<?php
# Functions used in configurator
#
# Copyright (C) 2003 Unix Solutions Ltd.
# Written by Georgi Chorbadzhiyski
#
# $Id: functions.php,v 1.5 2005/11/29 10:07:35 gf Exp $
#
# Redistribution and use of this script, with or without modification, is
# permitted provided that the following conditions are met:
#
# 1. Redistributions of this script must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
#  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
#  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
#  EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
#  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
#  ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

/*
	Format of the data file:

Definition of stock type

T;Montherboard;0

	T	- Stock type identificator
	xx	- Stock type
	0	- Do not allow count to be changed (1 == allow)

Definition of product

P;Product Name;Price

Example data.txt file

T;Motherboard;0
P;Tyan Tiger XP;80
P;ServerWorks;40
T;Fan;0
P;For Pentium 4;5.20
P;For Athlon;4.50
T;Memory;1
P;64Mb;15.20
P;128Mb;28
P;256Mb;43
T;Mouse;1
P;Logitech Wheel;4.50
P;Microsoft;1.50
*/
	// Load data file and return array
	function load_data_file($filename="data.txt") {
		global $DEBUG;

		$stocks = array();
		$lines = @file($filename);
		if (!is_array($lines)) {
			print "Can't open data file!";
		} else {
			$t = -1; // Current stock type
			$p = 1;  // Current stock
			foreach ($lines as $line_num => $line) {
				$line = rtrim($line); // Remove new line
				if ($DEBUG > 1)
					echo "Line #<b>{$line_num}</b> : " . htmlspecialchars($line) . "<br>\n";
				$l = explode(";", $line);
				if (is_array($l) && count($l) == 3) {
					if ($l[0] == "T") {
						$t++;
						$p = 1;
						$stocks[$t]['t'] = $l[1];
						$stocks[$t]['c'] = ($l[2] == 1)?'1':'0';
						$stocks[$t]['s'] = array();
						$stocks[$t]['p'] = array();
					} else
					if ($l[0] == "P") {
						$stocks[$t]['s'][$p] = $l[1];
						$stocks[$t]['p'][$p] = $l[2];
						$p++;
					}
				} else {
					if ($DEBUG)
						echo "Ignorring line: <b>" . htmlspecialchars($line) . "</b><br>\n";
				}
			}
		}
		return $stocks;
	}

	// Return array with submitted stocks
	function init_submitted_stocks(&$input) {
		$ret = array();
		if (!is_array($input))
			return $ret;
		foreach ($input as $field_name => $value) {
			// We're interreseted only in numbers
			if (!is_numeric($value))
				continue;
			// Use only stock and count fields
			if (ereg('([sc])([0-9]+)', $field_name, $matches)) {
				$type   = $matches[1]; // 's' == stockID, 'c' == count
				$typeid = $matches[2]; // type id (motherboard, cpu, fan...etc)
				if ($value > 0)
					$ret[$type][$typeid] = $value;
			}
		}
		return $ret;
	}

	// Transfrom PHP's $stocks array into JS stocks array
	function print_js_variables(&$indata) {
		print "// Initialize data\nx = Array();\n";
		if (!is_array($indata))
			return;
		foreach($indata as $i => $data) {
			if (!is_array($data))
				return;
			if (!is_array($data['s']) || !is_array($data['p']))
				return;
			$type = $data['t'];
			$usecount = $data['c'];
			print "
x[$i] = Array();
x[$i]['t'] = '$type';
x[$i]['c'] = $usecount;
x[$i]['s'] = Array();
x[$i]['p'] = Array();
";
			for ($r=1; $r<=count($data['s']); $r++) {
				$stock = $data['s'][$r];
				$price = $data['p'][$r];
				print "x[$i]['s'][$r]='$stock';x[$i]['p'][$r]=$price;\n";
			}
		}
		print "var stocks = x;\n";
	}

	/* Convert cyrillic to latin */
	function cyr_to_lat($data) {
		if (ereg('[-]',$data)) { $data = ereg_replace('','Zh',$data); } else { $data = ereg_replace('','ZH',$data); }
		if (ereg('[-]',$data)) { $data = ereg_replace('','Ch',$data); } else { $data = ereg_replace('','CH',$data); }
		if (ereg('[-]',$data)) { $data = ereg_replace('','Sh',$data); } else { $data = ereg_replace('','SH',$data); }
		if (ereg('[-]',$data)) { $data = ereg_replace('','Sht',$data); } else { $data = ereg_replace('','SHT',$data); }
		if (ereg('[-]',$data)) { $data = ereg_replace('','Iu',$data); } else { $data = ereg_replace('','IU',$data); }
		if (ereg('[-]',$data)) { $data = ereg_replace('','Ia',$data); } else { $data = ereg_replace('','IA',$data); }
		$data = strtr($data,'','ABVGDEZIYKLMNOPRSTUFHCAAAAC');

		$data = ereg_replace('','zh',$data);
		$data = ereg_replace('','ch',$data);
		$data = ereg_replace('','sh',$data);
		$data = ereg_replace('','sht',$data);
		$data = ereg_replace('','iu',$data);
		$data = ereg_replace('','ja',$data);
		$data = strtr($data,'','abvgdeziyklmnoprstufhcaaaac');
		return $data;
	}

	// Check if email is valid
	function valid_email($email,$check_mx=false) {
		$email_pattern = '/^\w+((-\w+)|(_\w+)|(\.\w+))*\@[a-z0-9]+((\.|-)[a-z0-9]+)*\.[a-zA-Z]{2,6}$/';
		$return = false;
		if (preg_match($email_pattern,strtolower($email)))
			$return = true;

		if ($return && $check_mx) {
			list($user,$host) = split('@',$email);
			$host .= '.';
			if ( getmxrr( $host, $mxhosts ) == false && gethostbyname( $host ) == $host )
				$return = false;
			else
				$return = true;
		}
		return $return;
	}

	// Send email, returns TRUE on success FALSE otherwise
	// $sendmode == 0 (as is)
	// $sendmode == 1 (+ latin)
	// $sendmode == 2 (only latin)
	function send_email($from,$fromname,$subject,$to,$body,$sendmode=0,$html=false) {
		$headers  = "From: $fromname <$from>\n";
		$headers .= "Reply-To: $from\n";
		$headers .= "Return-path: $from\n";
		if (!$html) {
			if ($sendmode != 2)
				$headers .= "Content-type: text/plain; charset=windows-1251\n";
		} else {
			$sendmode = 0;
			$headers .= "Content-type: text/html; charset=windows-1251\n";
		}
		$headers .= "Subject: $subject\n";
		$headers .= "X-Sender-Ip: ".ereg_replace("\n","",$_SERVER["REMOTE_ADDR"])."\n";
		if (isset($_SERVER["HTTP_VIA"]))
			$headers .= "X-Sender-Proxy: ".ereg_replace("\n","",$_SERVER["HTTP_VIA"])."\n";
		if (isset($_SERVER["HTTP_X_FORWARDED_FOR"]))
			$headers .= "X-Sender-Proxy: ".ereg_replace("\n","",$_SERVER["HTTP_X_FORWARDED_FOR"])."\n";
		if (isset($_SERVER["HTTP_USER_AGENT"]))
			$headers .= "X-Sender-UA: ".ereg_replace("\n","",$_SERVER["HTTP_USER_AGENT"])."\n";
		$headers .= "Subject: $subject\n";
		switch ($sendmode) {
			case 1: $body .= "\n\n--- Ako ne chetete kirilica ---\n\n".cyr_to_lat($body); break;
			case 2: $body = cyr_to_lat($body); break;
		}
		$body = ereg_replace("\r","",$body);
		return mail($to, $subject, $body, $headers);
	}
?>